/***********************************************************************************************************************
 *
 * blueBill Resources - open source birding
 * Copyright (C) 2009-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it
 * SCM: https://java.net/hg/bluebill~resources-src
 *
 **********************************************************************************************************************/
package it.tidalwave.bluebill.taxonomy.birds.ebn.italia;

import it.tidalwave.bluebill.taxonomy.birds.BirdTaxonomyImporter;
import javax.annotation.Nonnull;
import java.io.File;
import it.tidalwave.bluebill.taxonomy.birds.DefaultTranslator;
import it.tidalwave.bluebill.taxonomy.birds.GeneratorSupport;
import static it.tidalwave.bluebill.taxonomy.elmo.ElmoTaxonomyVocabulary.*;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class EbnItalia2011Generator extends GeneratorSupport
  {
    public static final String TAXONOMY_NAME = "EBN Italia 2011";
    public static final String TAXONOMY_FILE_NAME = "EBNItalia2011";

    public static void main (final @Nonnull String ... args)
      throws Exception
      {
        new EbnItalia2011Generator(args[0]).execute();
      }

    public EbnItalia2011Generator (final @Nonnull String baseDir)
      {
        super(baseDir, TAXONOMY_NAME, TAXONOMY_FILE_NAME);
      }

    @Nonnull
    public BirdTaxonomyImporter run()
      throws Exception
      {
        final EbnItalia2011Importer importer = new EbnItalia2011Importer();
        importer.setTaxonTranslator(new DefaultTranslator(EbnItalia2011Importer.class, "EbnItalia2011ToCatalogueOfLifeTranslations.config"));
        importer.setIdentifierMapFile(new File(resourcesFolder, "TaxonIdMap.txt.gz"));
        importer.setSourceResourceName("CL_Paleartico_occidentale 2011.csv");
        importer.run(repository, ID_TAXONOMY_PREFIX + "EBNItalia/2011");

        return importer;
      }
  }
